<?php
/**
 *	POWER + SITE   -  Core -> [CLASSE] Menu
 *	Auteur : Power + Techonologie  <http://power-plus-technologie.fr>
 *	Licence : Creative Commons BY-NC
 */
 
 
/**
 *	Classe PPMenu
 *	Gestion des menus dans la partie site
 */
class PPMenu {
	
	/**
	 *	@const  XML_URL  string  Contient l'URL du menu XML à partir du ROOT
	 */
	const XML_URL = 'core/conf/menu-site.xml';


	/**
	 *	@var  $_menuContents  SimpleXMLElement ressource  Menu
	 */
	protected $_menuContents;
	
	protected $_menuID;
	
	

	/**
	 *	Création de la classe PPMenu
	 *	@arg  $menuType  ressource PPMenu  Contient le type de menu
	 */
	public function __construct($id = false) {
		$this->_menuContents = simplexml_load_file(ROOT . PPMenu::XML_URL);
		
		$this->_menuID = $id;
	}

	
	protected function selectMenuID($id) {
		$retour = false;
		$xml = $this->_menuContents;
		foreach($xml->menu as $menu) {
			if($menu->attributes()->id == $id) {
				$retour = $menu;
			}
		}
		
		return $retour;
	}
	
	
	protected function _save() {
		$xml = $this->_menuContents->asXML();
		file_put_contents(ROOT . PPMenu::XML_URL, $xml);
	}


	public function listItems() {
		$itemArr = false;
		$xml = $this->selectMenuID($this->_menuID);
		foreach($xml->item as $item) {
			$m['id'] = (int) $item->attributes()->id;
			$m['type'] = (string) $item->attributes()->type;
			$m['text'] = (string) $item->attributes()->text;
			$m['ordre'] = (int) $item->attributes()->ordre;

			if($m['type'] == 'gadget') {
				foreach($item->option as $option) {
					$n[(string) $option->attributes()->name] = (string) $option;
					$m['options'] = $n;
				}
				$m['dossier'] = (string) $item->dossier;
			}
			else
				$m['url'] = (string) $item->attributes()->url;

			$itemArr[] = $m;
			$m = array();
		}
		return sortByKey($itemArr, 'ordre');
	}
	
	
	private function _nextId() {
		$xml = $this->_menuContents;
		$ids = array();
		foreach($xml->menu as $menu) {
			foreach($menu->item as $item) {
				$ids[] = (int) $item->attributes()->id;
			}
		}
		return max($ids) + 1;
	}
	
	
	public function getItem($id) {
		$i = $this->listItems($id);
		foreach($i as $item) {
			if($item['id'] == $id) {
				return $item;
				break;
			}
		}
	}
	
	
	public function listMenus() {
		$retour = array();
	
		$xml = $this->_menuContents;
		foreach($xml->menu as $menu) {
			$retour[] = $menu->attributes()->id;
		}
		return $retour;	
	}
	
	
	public function addItem($type, $text, $url = false, $dossier = false) {
		$xml = $this->selectMenuID($this->_menuID);
		$item = $xml->addChild('item');
		$item->addAttribute('id', $this->_nextId());
		$item->addAttribute('type', $type);
		$item->addAttribute('text', $text);
		if($url != false) {
			$item->addAttribute('url', $url);
		}
		if($type == 'gadget') {
			$item->addChild('dossier', $dossier);
		}
		$this->_save();
	}
	
	
	public function editItem($idSelect, $name, $value) {
		$xml = $this->selectMenuID($this->_menuID);

		$ids = array();
		$i = 0;

		foreach($xml->item as $item) {
			$ids[(int) $item->attributes()->id] = $i;
			$i++;
		}
		
		$selectNode = $xml->item[$ids[$idSelect]];
		
		if(isset($selectNode->attributes()->$name)) {
			$selectNode->attributes()->$name = $value;
		}
		else {
			$selectNode->addAttribute($name, $value);
		}
		
		$this->_save();
	}
	
	public function delItem($idSelect) {
		$xml = $this->selectMenuID($this->_menuID);

		$ids = array();
		$i = 0;

		foreach($xml->item as $item) {
			$ids[(int) $item->attributes()->id] = $i;
			$i++;
		}
		
		unset($xml->item[$ids[$idSelect]]);
		
		$this->_save();
	}
}
?>