<?php
/**
 *	POWER + SITE  -  Core -> [CLASS] Page
 *	Auteur : Power + Technologie <http://power-plus-technologie.fr>
 *	Licence : Creative Commons BY-NC
 */

if(!defined('ROOT')) {
	if(in_array('admin', explode('/', $_SERVER['REQUEST_URI'])))
		define('ROOT', '../');
	else
		define('ROOT', '');

	require ROOT . 'core/lib/load.php';
}

class Page {
	
	private $_pageTitre;

	//	Contient les pages de fonction
	private $pageFx = array();

	//	TRUE si page Admin, sinon FALSE
	private $pageAdmin = false;

	//	Contient le code HTML de la page
	private $tpl;

	//	Liste des classes disponibles à l'importation
	private $classImport = array('tag' => 'tag.class.php', 'textile' => 'textile.class.php', 'PPMail' => 'ppmail.class.php');
	
	//	Description de la page
	private $pageDescrib;
	
	//	Definition des chemins
	private $_page;
	private $_mainModele;
	private $_mainVue;
	
	private $_droits;
	
	
	private $_themeDir;

	private $_flux = false;
	
	const ZONE_ADMIN = true;

	
	/**
	 *	Quand on déclarre la classe, cette fonction est appellée automatiquement
	 *	elle permet de se connecter à la base de données, rechercher les fichiers indispensables
	 *	définir les droits de l'utilisateur.
	 *
	 *	@param  bool  $bool  est égale à TRUE si c'est une zone admin
	 */
	public function Page($rep = false) {
		if(is_bool($rep))
			$this->pageAdmin = $rep;
		
		if($rep)
			$this->_droits = 1;
		else
			$this->_droits = 5;
		
		session_start();
		
		//	Constantes pour l'utilisateur
		$is_connecte = false;
		$mbr_nom = '';
		$droits = array('proprio' => false, 'admin' => false, 'modo' => false);
		$droitId = 5;
		if(isset($_SESSION['connexion'])) {
			$usr = unserialize($_SESSION['connexion']);
			$is_connecte = true;
			$mbr_nom = $usr->get('nom');
			$droits = $usr->get('droits');
			$droitId = $usr->get('droitId');
		}
		define("IS_CONNECTE", $is_connecte);
		define("MBR_NOM", $mbr_nom);
		define("IS_PROPRIO", $droits['proprio']);
		define("IS_ADMIN", $droits['admin']);
		define("IS_MODO", $droits['modo']);
		define('DROIT_ID', $droitId);
		
		
		//	Définition du thème du site
		if($this->pageAdmin)
			$this->_themeDir = 'themes/admin/' . THEME_ADMIN;
		else
			$this->_themeDir = 'themes/' . THEME_SITE;
	}

	
	public function setPage($dir) {
		$this->_page = $dir;
		$this->_mainModele = $dir . '/main.modele.php';
		$this->_mainVue = $dir . '/main.vue.php';
	}
	
	public function setDroits($d) {
		$this->_droits = $d;
	}
	

	/**
	 *	Permet de définir le titre d'une page
	 *
	 *	@param  string  $titre  contient le nom de la page
	 */
	public function setTitre($titre) {
		$this->_pageTitre = $titre;
	}


	/**
	 *	Permet de définir la description dans la page
	 *
	 *	@param  string  $describ  contient la description de la page
	 */
	public function setDescription($describ) {
		$this->pageDescrib = $describ;
	}


	private function _getDescrib() {
		if(!empty($this->pageDescrib))
			$describ = $this->pageDescrib;
		else
			$describ = SITE_DESCRIPTION;
		return $describ;
	}


	/**
	 *	Permet d'ajouter une page de fonction
	 *
	 *	@param string $fx contient le chemin de la page de fonctions
	 */
	public function pageAjouterFx($fx) {
		$this->pageFx[] = $fx;
	}	


	/**
	 *	Permet d'importer de nouvelles classes
	 *
	 *	@param string $class  nom de la classe à importer
	 */
	public function import($class) {
		require_once(ROOT . 'core/lib/' . $this->classImport[$class]);
	}



	public function addFlux($type, $titre, $url) {
		$this->_flux[] = array('type' => $type, 'titre' => $titre, 'url' => $url);
	}


	/**
	 *	Renvoie le contenu de la page déjà parsé
	 *
	 *	@return  code HTML de la page parsée
	 */
	private function _getPage() {
		//	Recherche si un template personnalisé existe
		$vuePerso = preg_replace('#\.vue\.php$#', '.vueperso.php', $this->_mainVue);
		if(file_exists($vuePerso)) {
			$this->_mainVue = $vuePerso;
		}

		$droits = array('proprio', 'admin', 'modo', 'redacteur', 'membre');

		if($this->pageAdmin) {
			if(DROIT_ID > $this->_droits) {
				$this->_page = '../core/pages/admin-connect';
				$this->_mainVue = '../core/pages/admin-connect/main.vue.php';
			}
		}

		ob_start();
		if(($this->pageAdmin && DROIT_ID <= $this->_droits) || !$this->pageAdmin) {
			if($this->pageFx != "") {
				foreach($this->pageFx as $fx) {
					require($fx);
				}
			}
	
			if($this->_mainModele != "")
				require $this->_mainModele;
		}

		require $this->_mainVue;

		$html = ob_get_contents();
		ob_end_clean();
		
		return $html;
	}


	/**
	 *	Insérer le code générer de la page en HTML
	 */
	public function send() {
		$theme = new Theme($this->_themeDir);
		$theme->site['nom'] = SITE_NOM;
		$theme->site['slogan'] = SITE_SLOGAN;
		$theme->site['url'] = SITE_URL;
		$theme->site['contenu'] = $this->_getPage();
		if(file_exists(ROOT . 'core/conf/footer.txt')) {
			$theme->site['footer'] = file_get_contents(ROOT . 'core/conf/footer.txt');
		}
		else {
			$theme->site['footer'] = 'Site propulsé par <a href="http://ppsite.fr"><strong>Power + Site</strong></a>';
		}
		$theme->site['titre'] = $this->_pageTitre;
		$theme->flux = $this->_flux;
		$theme->send();
	}
}
?>